
-- GLOBALS: FILTER_LANGUAGE

--[[ Setup default ]]--
if type(FILTER_LANGUAGE) ~= "table" then
	FILTER_LANGUAGE = {
		debug = false,  -- Print messages about blocked items
		all = true,  -- Enable filtering of all non-English messages
		allp = 15,  -- Percent of non-English characters to allow
		blocked = 0,  -- Total number of blocked messages
		filterFunction = nil,
	}
end


local gsub, lower = gsub, string.lower
local IsBadLanguage = function(msg)
	if FILTER_LANGUAGE["all"] then
		return false
	end
	local msg_org = msg
	msg = lower(msg)
	msg = msg:gsub("(%d)", "") -- Remove numbers from string (don't include them in the percent)
	
	--[[ Old method, get percent of non-ascii characters (may go back to this method when filtering by language) ]]--
	--[[local count = 0;
	if #msg > 25 then
		for i=1, #msg do
			if msg:byte(i) < 32 or msg:byte(i) > 126 then
				count = count + 1
			end
		end
		local percent = count / #msg
		if percent >= FILTER_LANGUAGE["allp"] / 100 then
			if FILTER_LANGUAGE["debug"] then
				print(string.format("BLOCKED[%.2f] %s", percent, msg_org))
			end
			return true
		end
	end]]--
	
	--[[ New method, remove all ascii characters and get the percent difference ]]--
	local filtered_msg = msg:gsub("%a*%p*%s*", "") -- remove alpha, numeric, punctuation, space
	
	local percent = #filtered_msg / #msg
	if percent >= FILTER_LANGUAGE["allp"] / 100 then
		if FILTER_LANGUAGE["debug"] then
			print(string.format("BLOCKED[%.2f] %s", percent, msg_org))
		end
		return true
	end
end


local prevLineId, result
local Ambiguate = Ambiguate
local FilterFunction = function(_,event,msg,player,_,_,_,_,chanId,_,_,_,lineId)
	if lineId == prevLineId then
		return result
	else
		prevLineId, result = lineId, nil
		if chanId == 0 or chanId == 25 then return end --Don't scan custom channels or GuildRecruitment channel
		local trimmedPlayer = Ambiguate(player, "none")
		if not CanComplainChat(lineId) or UnitIsInMyGuild(trimmedPlayer) then return end --Don't filter ourself/friends
		local rawMsg = msg
		if IsBadLanguage(msg) then
			if BadBoyLog then BadBoyLog("Language", event, trimmedPlayer, rawMsg) end
			result = true
			return true
		end
	end
end

ChatFrame_AddMessageEventFilter("CHAT_MSG_CHANNEL", FilterFunction)

print("Filter language |r|cFFFF0000"..GetAddOnMetadata("Filter_Language","Version").."|r|cFFFFFFFF loaded")